run

Function run 

pub async fn run(ctl_path: &Path, ready_fd: Option<OwnedFd>) -> Result<()>
Run the daemon, listening on its socket.

If ready_fd is provided, a single byte is written to it after the socket is bound, then the fd is dropped. This unblocks the parent process after daemonize() forks.