pub fn verify_peer_uid(stream: &UnixStream) -> Result<()>Expand description
Verify that the peer on a Unix stream has the same UID as the current process.
pub fn verify_peer_uid(stream: &UnixStream) -> Result<()>Verify that the peer on a Unix stream has the same UID as the current process.