Module connect

Module connect 

Structs

ConnectOpts
TunnelInfo

Enums

TunnelStatus
Tunnel health status.

Functions

connection_socket_path
Compute the local socket path for a given connection name. Public so main.rs can compute the path in the parent process after daemonize.
disconnect
get_tunnel_info
Gather info for all live tunnels (cleans stale ones as a side effect).
list_tunnels
parse_host
Extract the host component from a destination string ([user@]host[:port]).
run