Structs
Enums
- Tunnel
Status - Tunnel health status.
Functions
- connection_
socket_ path - Compute the local socket path for a given connection name. Public so main.rs can compute the path in the parent process after daemonize.
- disconnect
- get_
tunnel_ info - Gather info for all live tunnels (cleans stale ones as a side effect).
- list_
tunnels - parse_
host - Extract the host component from a destination string (
[user@]host[:port]). - run