Module connect

Module connect 

Structs

ConnectOpts

Enums

TunnelStatus
Tunnel health status.

Functions

connection_socket_path
Compute the local socket path for a given connection name. Public so main.rs can compute the path in the parent process after daemonize.
disconnect
list_tunnels
run