pub fn connection_socket_path(connection_name: &str) -> PathBuf
Compute the local socket path for a given connection name. Public so main.rs can compute the path in the parent process after daemonize.